@@ -3,6 +3,7 @@ from __future__ import annotations
 from contextlib import AsyncExitStack, ExitStack, contextmanager
 from types import TracebackType
 from typing import (
+    TYPE_CHECKING,
     Any,
     ContextManager,
     Dict,
@@ -26,13 +27,14 @@ from di.types.scopes import Scope
 
 
 class ContainerState(object):
-
-    __slots__ = ("binds", "cached_values", "stacks")
+    binds: Dict[DependencyProvider, DependantProtocol[Any]]
+    cached_values: ScopeMap[DependencyProvider, Any]
+    stacks: Dict[Scope, Union[AsyncExitStack, ExitStack]]
 
     def __init__(self) -> None:
-        self.binds: Dict[DependencyProvider, DependantProtocol[Any]] = {}
-        self.cached_values = ScopeMap[DependencyProvider, Any]()
-        self.stacks: Dict[Scope, Union[AsyncExitStack, ExitStack]] = {}
+        self.binds = {}
+        self.cached_values = ScopeMap()
+        self.stacks = {}
 
     def copy(self) -> "ContainerState":
         new = ContainerState()
@@ -84,7 +86,9 @@ class ScopeContext(FusedContextManager[None]):
         exc_value: Optional[BaseException],
         traceback: Optional[TracebackType],
     ) -> Union[None, bool]:
-        stack = cast(ExitStack, self.state.stacks[self.scope])
+        stack = self.state.stacks[self.scope]
+        if TYPE_CHECKING:
+            stack = cast(ExitStack, stack)
         self.state.stacks.pop(self.scope)
         self.state.cached_values.pop_scope(self.scope)
         return stack.__exit__(exc_type, exc_value, traceback)
@@ -99,7 +103,9 @@ class ScopeContext(FusedContextManager[None]):
         exc_value: Optional[BaseException],
         traceback: Optional[TracebackType],
     ) -> Union[None, bool]:
-        stack = cast(AsyncExitStack, self.state.stacks[self.scope])
+        stack = self.state.stacks[self.scope]
+        if TYPE_CHECKING:
+            stack = cast(AsyncExitStack, stack)
         self.state.stacks.pop(self.scope)
         self.state.cached_values.pop_scope(self.scope)
         return await stack.__aexit__(exc_type, exc_value, traceback)
