@@ -42,22 +42,31 @@ from di.types.solved import SolvedDependency
 
 
 class Container:
+    _context: ContextVar[ContainerState]
+    _executor: Union[AsyncExecutor, SyncExecutor]
+
     def __init__(
-        self, executor: Optional[Union[AsyncExecutor, SyncExecutor]] = None
+        self,
+        *,
+        default_scope: Scope = None,
+        executor: Optional[Union[AsyncExecutor, SyncExecutor]] = None,
     ) -> None:
-        self._context = ContextVar[ContainerState]("context")
+        self._context = ContextVar("context")
         state = ContainerState()
         state.cached_values.add_scope("container")
         state.cached_values.set(Container, self, scope="container")
         self._context.set(state)
-        self._executor: Union[AsyncExecutor, SyncExecutor] = (
-            executor or DefaultExecutor()
-        )
+        self._executor = executor or DefaultExecutor()
+        self._default_scope = default_scope
 
     @property
     def _state(self) -> ContainerState:
         return self._context.get()
 
+    @property
+    def scopes(self) -> List[Scope]:
+        return self._state.scopes
+
     def enter_global_scope(self, scope: Scope) -> FusedContextManager[None]:
         """Enter a global scope that is share amongst threads and coroutines.
 
@@ -93,6 +102,14 @@ class Container:
         """
         return self._state.bind(provider=provider, dependency=dependency)
 
+    def __contains__(self, o: object) -> bool:
+        return o in self._state.binds
+
+    def __getitem__(
+        self, provider: DependencyProviderType[DependencyType]
+    ) -> DependantProtocol[DependencyType]:
+        return self._state.binds[provider]
+
     def solve(
         self, dependency: DependantProtocol[DependencyType]
     ) -> SolvedDependency[DependencyType]:
@@ -247,7 +264,7 @@ class Container:
         and then disable scope validation in subsequent runs with `validate_scope=False`.
         """
         results: Dict[Task[Any], Any] = {}
-        with self.enter_local_scope(None):
+        with self.enter_local_scope(self._default_scope):
             if validate_scopes:
                 self._validate_scopes(solved)
 
@@ -276,7 +293,7 @@ class Container:
         and then disable scope validation in subsequent runs with `validate_scope=False`.
         """
         results: Dict[Task[Any], Any] = {}
-        async with self.enter_local_scope(None):
+        async with self.enter_local_scope(self._default_scope):
             if validate_scopes:
                 self._validate_scopes(solved)
 
